==> bitcoin-0.15.1.tar.gz: bitcoin-0.15.1/src/qt/locale/bitcoin_th.ts <==
<TS language="th" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>คลิกขวาเพื่อแก้ไขที่อยู่หรือชื่อ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>สร้างที่อยู่ใหม่</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>ใหม่</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>คัดลอกที่อยู่ที่เลือกอยู่ไปยังคลิบบอร์ดของระบบ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>คัดลอก</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>ลบที่อยู่ที่เลือกไว้ออกจากรายการ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ส่งออกข้อมูลที่อยู่ในแถบนี้ไปในไฟล์</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>ส่งออก</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>ลบ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>เลือกที่อยู่ที่จะส่งเหรียญ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>เลือกที่อยู่ที่จะรับเหรียญ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>เลือก</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>ที่อยู่ในการส่ง</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>ที่อยู่ในการรับ</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>คัดลอกที่อยู่</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>คัดลอกชื่อ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>แก้ไข</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>การส่งออกล้มเหลว</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>การส่งออกล้มเหลว</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>ส่งออก</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ส่งออกข้อมูลที่อยู่ในแถบนี้ไปในไฟล์</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-0.16.0.tar.gz: bitcoin-0.16.0/src/qt/locale/bitcoin_th.ts <==
<TS language="th" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>คลิกขวาเพื่อแก้ไขที่อยู่หรือชื่อ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>สร้างที่อยู่ใหม่</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>ใหม่</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>คัดลอกที่อยู่ที่เลือกอยู่ไปยังคลิบบอร์ดของระบบ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>คัดลอก</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>ปิด</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>ลบที่อยู่ที่เลือกไว้ออกจากรายการ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ส่งออกข้อมูลที่อยู่ในแถบนี้ไปในไฟล์</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>ส่งออก</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>ลบ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>เลือกที่อยู่ที่จะส่งเหรียญ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>เลือกที่อยู่ที่จะรับเหรียญ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>เลือก</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>ที่อยู่ในการส่ง</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>ที่อยู่ในการรับ</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>ที่อยู่ Bitcoin ของคุณสำหรับการส่งการชำระเงิน โปรดตรวจสอบจำนวนเงินและที่อยู่รับก่อนที่จะส่งเหรียญ</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>ที่อยู่ Bitcoin ของคุณสำหรับการรับเงิน แนะนำให้ใช้ที่อยู่รับใหม่สำหรับแต่ละธุรกรรม</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>คัดลอกที่อยู่</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>คัดลอกชื่อ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>แก้ไข</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>ส่งออกรายการที่อยู่</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ไฟล์ที่คั่นด้วยจุลภาค (* .csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>การส่งออกล้มเหลว</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ฉลาก, ป้าย,</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีฉลาก)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>กล่องโต้ตอบวลีรหัสผ่าน</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>ป้อนวลีรหัสผ่าน</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>วลีรหัสผ่านใหม่</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>ทำซ้ำข้อความรหัสใหม่</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>กระเป๋าสตางค์ เข้ารหัส</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>การดำเนินการนี้ต้องการกระเป๋าสตางค์กระเป๋าสตางค์ของคุณเพื่อปลดล็อกกระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>ปลดล็อค กระเป๋าสตางค์ </translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>การดำเนินการนี้ ต้องการ รหัสผ่าน กระเป๋าสตางค์ ของคุณ เพื่อ ถอดรหัส กระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>ถอดรหัส กระเป๋าสตางค์</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>เปลี่ยน ข้อความรหัสผ่าน</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีฉลาก)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ฉลาก, ป้าย,</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>ฉลาก, ป้าย,</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีฉลาก)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีฉลาก)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>ฉลาก, ป้าย,</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ไม่มีฉลาก)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ไฟล์ที่คั่นด้วยจุลภาค (* .csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ฉลาก, ป้าย,</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>ที่อยู่</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>การส่งออกล้มเหลว</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>ส่งออก</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ส่งออกข้อมูลที่อยู่ในแถบนี้ไปในไฟล์</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
